# jhwhois

[![Build Status](https://github.com/crazzy/jhwhois/actions/workflows/python-app.yml/badge.svg)](https://github.com/crazzy/jhwhois/actions/workflows/python-app.yml)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

## Why?

Because I got fed up with various existing whois clients always querying the wrong server and the best one I could find, jwhois, haven't been updated in years. The default configuration is anything but good, it has a big tendency to query RADB for almost anything, an un-official database full of incorrect data.

## So is it better?

For my use-cases it's way better than the others I've tried starting from very early in the development of it. For any other imaginable use-case, maybe not. I don't care, I made this for myself and nobody else.

## I have a suggestion!

Feel free to open an issue or a PR and I'll take a look at it.

## The code sucks!

I'm a network engineer, not a developer, so I'm 100% positive there's better ways to do certain things.

## Documentation?

Read the code.

## So how about using this?

    pip install jhwhois
